@@ -1,25 +1,9 @@
 /*
   This file is part of KJots.
 
-  Copyright (c) 2008 Stephen Kelly <steveire@gmail.com>
+  SPDX-FileCopyrightText: 2008 Stephen Kelly <steveire@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "aboutdata.h"
@@ -33,7 +17,7 @@ AboutData::AboutData()
                  QStringLiteral(KJOTS_VERSION),
                  i18n("KDE note taking utility"),
                  KAboutLicense::GPL,
-                 i18n("Copyright © 1997–2020 KJots authors"))
+                 i18n("Copyright © 1997–2023 KJots authors"))
 {
     addAuthor(i18n("Igor Poboiko"), i18n("Maintainer"), QStringLiteral("igor.poboiko@gmail.com"));
     addAuthor(i18n("Daniel Vrátil"), i18n("Port to KDE Frameworks 5"), QStringLiteral("dvraitl@kde.org"));
