@@ -1,33 +1,24 @@
 /*
     This file is part of KJots.
 
-    Copyright (C) 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
+    SPDX-FileCopyrightText: 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
                   2002, 2003 Aaron J. Seigo <aseigo@kde.org>
                   2003 Stanislav Kljuhhin <crz@hot.ee>
                   2005-2006 Jaison Lee <lee.jaison@gmail.com>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 //Own Header
 #include "kjotsbrowser.h"
 #include "kjotsmodel.h"
 
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeechWidget>
+#endif
+
 #include <KPIMTextEdit/RichTextEditFindBar>
-#include <KPIMTextEdit/TextToSpeechWidget>
 #include <KPIMTextEdit/SlideContainer>
 
 #include <QHelpEvent>
@@ -49,14 +40,18 @@ public:
         : mBrowser(std::move(browser))
         , mSliderContainer(widget)
         , mFindBar(mBrowser.get(), &mSliderContainer)
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
         , mTextToSpeechWidget(widget)
+#endif
     {
     }
 
     std::unique_ptr<KJotsBrowser> mBrowser;
     KPIMTextEdit::SlideContainer mSliderContainer;
     KPIMTextEdit::RichTextEditFindBar mFindBar;
-    KPIMTextEdit::TextToSpeechWidget mTextToSpeechWidget;
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+    TextEditTextToSpeech::TextToSpeechWidget mTextToSpeechWidget;
+#endif
 };
 
 KJotsBrowserWidget::KJotsBrowserWidget(std::unique_ptr<KJotsBrowser> browser, QWidget *parent)
@@ -68,11 +63,15 @@ KJotsBrowserWidget::KJotsBrowserWidget(std::unique_ptr<KJotsBrowser> browser, QW
     d->mFindBar.setHideWhenClose(false);
 
     connect(&d->mFindBar, &KPIMTextEdit::RichTextEditFindBar::hideFindBar, this, &KJotsBrowserWidget::slotHideFindBar);
-    connect(d->mBrowser.get(), &KJotsBrowser::say, &d->mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+    connect(d->mBrowser.get(), &KJotsBrowser::say, &d->mTextToSpeechWidget, &TextEditTextToSpeech::TextToSpeechWidget::say);
+#endif
 
     QVBoxLayout *lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     lay->addWidget(&d->mTextToSpeechWidget);
+#endif
     lay->addWidget(d->mBrowser.get());
     lay->addWidget(&d->mSliderContainer);
 }
@@ -140,8 +139,9 @@ void KJotsBrowser::contextMenuEvent(QContextMenuEvent *event)
     }
     popup->addSeparator();
     popup->addAction(m_actionCollection->action(QString::fromLatin1(KStandardAction::name(KStandardAction::Find))));
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     popup->addSeparator();
-    if (!document()->isEmpty() && KPIMTextEdit::TextToSpeech::self()->isReady()) {
+    if (!document()->isEmpty() && TextEditTextToSpeech::TextToSpeech::self()->isReady()) {
         QAction *speakAction = popup->addAction(i18nc("@info:action", "Speak Text"));
         speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
         connect(speakAction, &QAction::triggered, this, [this](){
@@ -149,6 +149,7 @@ void KJotsBrowser::contextMenuEvent(QContextMenuEvent *event)
                 Q_EMIT say(text);
             });
     }
+#endif
     popup->exec(event->globalPos());
     delete popup;
 }
@@ -180,7 +181,11 @@ void KJotsBrowser::tooltipEvent(QHelpEvent *event)
                    && url.fragment().startsWith(QLatin1String("page_")))
         {
             bool ok;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             Item::Id id = url.fragment().midRef(5).toInt(&ok);
+#else
+            Item::Id id = QStringView(url.fragment()).mid(5).toInt(&ok);
+#endif
             const QModelIndexList idxs = EntityTreeModel::modelIndexesForItem(m_model, Item(id));
             if (ok && !idxs.isEmpty()) {
                 idx = idxs.first();
