@@ -1,26 +1,14 @@
 /*
     This file is part of KJots.
 
-    Copyright (C) 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
+    SPDX-FileCopyrightText: 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
                   2002, 2003 Aaron J. Seigo <aseigo@kde.org>
                   2003 Stanislav Kljuhhin <crz@hot.ee>
                   2005-2006 Jaison Lee <lee.jaison@gmail.com>
                   2007-2008 Stephen Kelly <steveire@gmail.com>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 //Own Header
@@ -45,7 +33,8 @@
 #include <KPIMTextEdit/RichTextComposerActions>
 #include <KPIMTextEdit/RichTextComposerImages>
 
-#include <AkonadiCore/Item>
+#include <akonadi_version.h>
+#include <Akonadi/Item>
 
 #include "kjotslinkdialog.h"
 #include "kjotsmodel.h"
@@ -146,7 +135,7 @@ void KJotsEdit::createActions(KActionCollection *ac)
     d->editorActionList.append(d->action_insert_date);
     if (ac) {
         ac->addAction(QStringLiteral("insert_date"), d->action_insert_date);
-        ac->setDefaultShortcut(d->action_insert_date, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_I));
+        ac->setDefaultShortcut(d->action_insert_date, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_I));
     }
 
     d->action_save = KStandardAction::save(this, &KJotsEdit::savePage, ac);
@@ -172,7 +161,7 @@ void KJotsEdit::setEnableActions(bool enable)
     // FIXME: RichTextComposer::setEnableActions(enable) messes with indent actions
     // due to bug in KPIMTextEdit (should be fixed in 20.08?)
     composerActions()->setActionsEnabled(enable);
-    for (QAction *action : qAsConst(d->editorActionList)) {
+    for (QAction *action : std::as_const(d->editorActionList)) {
         action->setEnabled(enable);
     }
 }
@@ -441,7 +430,7 @@ void KJotsEdit::leaveEvent(QEvent *event)
 
 void KJotsEdit::mousePressEvent(QMouseEvent *event)
 {
-    QUrl url = anchorAt(event->pos());
+    const QUrl url = QUrl(anchorAt(event->pos()));
     if ((event->modifiers() & Qt::ControlModifier) && (event->button() & Qt::LeftButton) && !url.isEmpty()) {
         Q_EMIT linkClicked(url);
     } else {
