@@ -1,22 +1,10 @@
 /*
     This file is a part of KJots.
 
-    Copyright (C) 2008 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2008 Stephen Kelly <steveire@gmail.com>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kjotslinkdialog.h"
@@ -47,7 +35,7 @@ KJotsLinkDialog::KJotsLinkDialog(QAbstractItemModel *kjotsModel, QWidget *parent
     ui->hrefCombo->setInsertPolicy(QComboBox::NoInsert);
     ui->hrefCombo->setCurrentIndex(-1);
 
-    auto *completer = new QCompleter(m_descendantsProxyModel.get(), this);
+    auto completer = new QCompleter(m_descendantsProxyModel.get(), this);
     completer->setCaseSensitivity(Qt::CaseInsensitive);
     ui->hrefCombo->setCompleter(completer);
 
