@@ -1,23 +1,10 @@
 /*
     This file is part of KJots.
 
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kjotsmodel.h"
@@ -26,20 +13,20 @@
 #include <QTextDocument>
 #include <QIcon>
 
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <Akonadi/Notes/NoteUtils>
+#include <akonadi_version.h>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/NoteUtils>
 
 #include <KMime/Message>
 #include <KPIMTextEdit/TextUtils>
 #include <KPIMTextEdit/RichTextComposerImages>
+#include <KPIMTextEdit/TextHTMLBuilder>
+#include <KPIMTextEdit/MarkupDirector>
+#include <KPIMTextEdit/PlainTextMarkupBuilder>
 #include <KLocalizedString>
 #include <KFormat>
 
-#include <grantlee/markupdirector.h>
-#include <grantlee/texthtmlbuilder.h>
-#include <grantlee/plaintextmarkupbuilder.h>
-
 #include "noteshared/notelockattribute.h"
 #include "noteshared/notepinattribute.h"
 
@@ -71,8 +58,8 @@ QString KJotsEntity::content() const
         return QString();
     }
 
-    Grantlee::TextHTMLBuilder builder;
-    Grantlee::MarkupDirector director(&builder);
+    KPIMTextEdit::TextHTMLBuilder builder;
+    KPIMTextEdit::MarkupDirector director(&builder);
 
     director.processDocument(document);
     QString result = builder.getResult();
@@ -87,11 +74,11 @@ QString KJotsEntity::plainContent() const
         return QString();
     }
 
-    Grantlee::PlainTextMarkupBuilder builder;
-    Grantlee::MarkupDirector director(&builder);
+    KPIMTextEdit::PlainTextMarkupBuilder builder;
+    KPIMTextEdit::MarkupDirector director(&builder);
 
     director.processDocument(document);
-    QString result = builder.getResult();
+    const QString result = builder.getResult();
 
     return result;
 }
@@ -208,7 +195,7 @@ bool KJotsModel::setData(const QModelIndex &index, const QVariant &value, int ro
 QVariant KJotsModel::data(const QModelIndex &index, int role) const
 {
     if (GrantleeObjectRole == role) {
-        auto *obj = new KJotsEntity(index);
+        auto obj = new KJotsEntity(index);
         obj->setIndex(index);
         return QVariant::fromValue(obj);
     }
@@ -225,7 +212,7 @@ QVariant KJotsModel::data(const QModelIndex &index, int role) const
 
         NoteUtils::NoteMessageWrapper note(item.payload<KMime::Message::Ptr>());
         const QString doc = note.text();
-        auto *document = new QTextDocument();
+        auto document = new QTextDocument();
         if (note.textFormat() == Qt::RichText
                 || doc.startsWith(u"<!DOCTYPE")
                 || doc.startsWith(u"<html>"))
@@ -239,7 +226,7 @@ QVariant KJotsModel::data(const QModelIndex &index, int role) const
         const QVector<NoteUtils::Attachment> attachments = note.attachments();
         for (const auto &attachment : attachments) {
             if (attachment.mimetype() == QStringLiteral("image/png") && !attachment.contentID().isEmpty()) {
-                QImage img = QImage::fromData(attachment.data(), "PNG");
+                const QImage img = QImage::fromData(attachment.data(), "PNG");
                 document->addResource(QTextDocument::ImageResource,
                                       QUrl(QStringLiteral("cid:")+attachment.contentID()), img);
             }
