@@ -1,29 +1,22 @@
 /*
     This file is part of KJots.
 
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KJOTSMODEL_H
 #define KJOTSMODEL_H
 
+#include <akonadi_version.h>
+#include <QtGlobal> // for QT_VERSION_CHECK
+#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
+#include <Akonadi/EntityTreeModel>
+#else
 #include <AkonadiCore/EntityTreeModel>
+#endif
 
 class QTextDocument;
 
