@@ -1,27 +1,14 @@
 /*
     This file is part of KJots.
 
-    Copyright (C) 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
+    SPDX-FileCopyrightText: 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
                   2002, 2003 Aaron J. Seigo <aseigo@kde.org>
                   2003 Stanislav Kljuhhin <crz@hot.ee>
                   2005-2006 Jaison Lee <lee.jaison@gmail.com>
                   2007-2009 Stephen Kelly <steveire@gmail.com>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kjotswidget.h"
@@ -45,29 +32,36 @@
 #include <QItemDelegate>
 #include <QHeaderView>
 #include <QDebug>
+#include <QActionGroup>
 
 // Akonadi
-#include <Akonadi/Notes/NoteUtils>
-#include <AkonadiCore/AttributeFactory>
-#include <AkonadiCore/CollectionCreateJob>
-#include <AkonadiCore/CollectionDeleteJob>
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/EntityMimeTypeFilterModel>
-#include <AkonadiCore/Item>
-#include <AkonadiCore/ItemCreateJob>
-#include <AkonadiCore/ItemModifyJob>
-#include <AkonadiCore/ItemDeleteJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/EntityOrderProxyModel>
-#include <AkonadiWidgets/EntityTreeView>
-#include <AkonadiWidgets/ETMViewStateSaver>
-#include <AkonadiWidgets/ControlGui>
+#include <akonadi_version.h>
+#include <Akonadi/NoteUtils>
+#include <Akonadi/AttributeFactory>
+#include <Akonadi/CollectionCreateJob>
+#include <Akonadi/CollectionDeleteJob>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/Item>
+#include <Akonadi/ItemCreateJob>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/EntityOrderProxyModel>
+#include <Akonadi/EntityTreeView>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/ControlGui>
 
-// Grantlee
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/template.h>
 #include <grantlee/engine.h>
 #include <grantlee/context.h>
+#else
+#include <KTextTemplate/Engine>
+#include <KTextTemplate/Template>
+#include <KTextTemplate/Context>
+#endif
 
 // KDE
 #include <KActionCollection>
@@ -105,8 +99,11 @@
 #include <memory>
 
 using namespace Akonadi;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 using namespace Grantlee;
-
+#else
+using namespace KTextTemplate;
+#endif
 KJotsWidget::KJotsWidget(QWidget *parent, KXMLGUIClient *xmlGuiClient, Qt::WindowFlags f)
     : QWidget(parent, f)
     , m_xmlGuiClient(xmlGuiClient)
@@ -135,7 +132,7 @@ KJotsWidget::KJotsWidget(QWidget *parent, KXMLGUIClient *xmlGuiClient, Qt::Windo
     scope.fetchAttribute<NoteShared::NoteLockAttribute>();
     scope.fetchAttribute<NoteShared::NotePinAttribute>();
 
-    auto *monitor = new ChangeRecorder(this);
+    auto monitor = new ChangeRecorder(this);
     monitor->fetchCollection(true);
     monitor->setItemFetchScope(scope);
     monitor->setCollectionMonitored(Collection::root());
@@ -216,8 +213,8 @@ KJotsWidget::~KJotsWidget()
 void KJotsWidget::setupGui()
 {
     // Main horizontal layout
-    auto *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    auto layout = new QHBoxLayout(this);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     // Splitter between (collection view) and (item view + editor)
     m_splitter1 = new QSplitter(this);
@@ -271,13 +268,13 @@ void KJotsWidget::setupGui()
 void KJotsWidget::restoreState()
 {
     {
-        auto *saver = new ETMViewStateSaver;
+        auto saver = new ETMViewStateSaver;
         saver->setView(m_collectionView);
         KConfigGroup cfg(KSharedConfig::openConfig(), "CollectionViewState");
         saver->restoreState(cfg);
     }
     {
-        auto *saver = new ETMViewStateSaver;
+        auto saver = new ETMViewStateSaver;
         saver->setView(m_itemView);
         KConfigGroup cfg(KSharedConfig::openConfig(), "ItemViewState");
         saver->restoreState(cfg);
@@ -344,7 +341,7 @@ void KJotsWidget::setupActions()
     m_actionManager->createAllActions();
 
     actionCollection->setDefaultShortcut(m_actionManager->action(StandardActionManager::CreateCollection),
-                                         QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_N));
+                                         QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_N));
 
     QAction *action;
     // Standard actions
@@ -353,13 +350,13 @@ void KJotsWidget::setupActions()
     action = KStandardAction::next(this, [this](){
             m_itemView->selectionModel()->select(previousNextEntity(m_itemView, +1), QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
         }, actionCollection);
-    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_PageDown));
+    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_PageDown));
     connect(this, &KJotsWidget::canGoNextPageChanged, action, &QAction::setEnabled);
 
     action = KStandardAction::prior(this, [this](){
             m_itemView->selectionModel()->select(previousNextEntity(m_itemView, -1), QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
         }, actionCollection);
-    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_PageUp));
+    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_PageUp));
     connect(this, &KJotsWidget::canGoPreviousPageChanged, action, &QAction::setEnabled);
 
     KStandardAction::renameFile(this, [this](){
@@ -385,7 +382,7 @@ void KJotsWidget::setupActions()
             }
         }, actionCollection);
     // Default Shift+Delete is ambiguous and used both for cut and delete
-    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_Delete));
+    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_Delete));
 
     action = KStandardAction::copy(this, [this](){
             activeEditor()->copy();
@@ -422,9 +419,9 @@ void KJotsWidget::setupActions()
     // Bookmarks actions
     auto *bookmarkMenu = actionCollection->add<KActionMenu>(QStringLiteral("bookmarks"));
     bookmarkMenu->setText(i18n("&Bookmarks"));
-    auto *bookmarks = new KJotsBookmarks(m_collectionView->selectionModel(), this);
+    auto bookmarks = new KJotsBookmarks(m_collectionView->selectionModel(), this);
     connect(bookmarks, &KJotsBookmarks::openLink, this, &KJotsWidget::openLink);
-    auto *bmm = new KBookmarkMenu(
+    auto bmm = new KBookmarkMenu(
         KBookmarkManager::managerForFile(
             QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/kjots/bookmarks.xml"),
             QStringLiteral("kjots")),
@@ -462,7 +459,7 @@ void KJotsWidget::setupActions()
     action = actionCollection->addAction(QStringLiteral("go_next_book"));
     action->setText(i18n("Next Book"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_PageDown));
+    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_PageDown));
     connect(action, &QAction::triggered, this, [this](){
             const QModelIndex idx = previousNextEntity(m_collectionView, +1);
             m_collectionView->selectionModel()->select(idx, QItemSelectionModel::SelectCurrent);
@@ -473,7 +470,7 @@ void KJotsWidget::setupActions()
     action = actionCollection->addAction(QStringLiteral("go_prev_book"));
     action->setText(i18n("Previous Book"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
-    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_PageUp));
+    actionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_PageUp));
     connect(action, &QAction::triggered, this, [this](){
             const QModelIndex idx = previousNextEntity(m_collectionView, -1);
             m_collectionView->selectionModel()->select(idx, QItemSelectionModel::SelectCurrent);
@@ -540,7 +537,7 @@ void KJotsWidget::updateMenu()
             ->setEnabled((itemsSelected == 1) || (m_collectionView->hasFocus() && collectionsSelected == 1));
 
     // Actions available when at least something is shown
-    for (QAction *action : qAsConst(anySelectionActions)) {
+    for (QAction *action : std::as_const(anySelectionActions)) {
         action->setEnabled(selectionSize >= 1);
     }
 }
@@ -551,7 +548,12 @@ void KJotsWidget::configure()
         return;
     }
     auto* dialog = new KConfigDialog(this, QStringLiteral("kjotssettings"), KJotsSettings::self());
-    dialog->addPage(new KJotsConfigMisc(dialog), i18nc("@title:window config dialog page", "Misc"), QStringLiteral("preferences-other"));
+    auto configMisc = new KJotsConfigMisc(dialog);
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    dialog->addPage(configMisc, i18nc("@title:window config dialog page", "Misc"), QStringLiteral("preferences-other"));
+#else
+    dialog->addPage(configMisc->widget(), i18nc("@title:window config dialog page", "Misc"), QStringLiteral("preferences-other"));
+#endif
     connect(dialog, &KConfigDialog::settingsChanged, this, &KJotsWidget::updateConfiguration);
     dialog->show();
 }
@@ -587,11 +589,19 @@ QString KJotsWidget::renderSelectionTo(const QString &theme, const QString &temp
     }
     QHash<QString, QVariant> hash = {{QStringLiteral("entities"), objectList},
                                      {QStringLiteral("i18n_TABLE_OF_CONTENTS"), i18nc("Header for 'Table of contents' section of rendered output", "Table of contents")}};
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Context c(hash);
+#else
+    KTextTemplate::Context c(hash);
+#endif
 
     const QString currentTheme = m_loader->themeName();
     m_loader->setTheme(theme);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Template t = m_templateEngine->loadByName(templ);
+#else
+    KTextTemplate::Template t = m_templateEngine->loadByName(templ);
+#endif
     const QString result = t->render(&c);
     m_loader->setTheme(currentTheme);
     return result;
@@ -772,7 +782,7 @@ void KJotsWidget::openLink(const QUrl &url)
             m_itemView->selectionModel()->select(idx, QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
         }
     } else {
-        auto *job = new KIO::OpenUrlJob(url, this);
+        auto job = new KIO::OpenUrlJob(url, this);
         job->start();
     }
 }
