@@ -1,27 +1,14 @@
 /*
     This file is part of KJots.
 
-    Copyright (C) 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
+    SPDX-FileCopyrightText: 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
                   2002, 2003 Aaron J. Seigo <aseigo@kde.org>
                   2003 Stanislav Kljuhhin <crz@hot.ee>
                   2005-2006 Jaison Lee <lee.jaison@gmail.com>
                   2007-2009 Stephen Kelly <steveire@gmail.com>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KJOTSWIDGET_H
@@ -31,9 +18,15 @@
 #include <QAbstractItemDelegate>
 #include <QPrinter>
 
-#include <AkonadiCore/Collection>
+#include <akonadi_version.h>
+#include <Akonadi/Collection>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/templateloader.h>
+#else
+#include <KTextTemplate/TemplateLoader>
+#endif
+
 
 class QActionGroup;
 class QCheckBox;
@@ -61,7 +54,11 @@ class EntityTreeView;
 class StandardNoteActionManager;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 namespace Grantlee
+#else
+namespace KTextTemplate
+#endif
 {
 class Engine;
 }
@@ -136,8 +133,13 @@ private Q_SLOTS:
     void print(QPrinter *printer);
 private:
     // Grantlee
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Engine *m_templateEngine = nullptr;
     QSharedPointer<Grantlee::FileSystemTemplateLoader> m_loader;
+#else
+    KTextTemplate::Engine *m_templateEngine = nullptr;
+    QSharedPointer<KTextTemplate::FileSystemTemplateLoader> m_loader;
+#endif
 
     // XMLGui && Actions
     KXMLGUIClient  *m_xmlGuiClient = nullptr;
