@@ -1,24 +1,12 @@
 /*
     This file is part of KJots.
 
-    Copyright (C) 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
+    SPDX-FileCopyrightText: 1997 Christoph Neerfeld <Christoph.Neerfeld@home.ivm.de>
                   2002, 2003 Aaron J. Seigo <aseigo@kde.org>
                   2003 Stanislav Kljuhhin <crz@hot.ee>
                   2005-2006 Jaison Lee <lee.jaison@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "KJotsMain.h"
@@ -35,9 +23,9 @@
 
 int main(int argc, char **argv)
 {
-    AboutData aboutData;
     KontactInterface::PimUniqueApplication app(argc, &argv);
     KLocalizedString::setApplicationDomain("kjots");
+    AboutData aboutData;
     app.setAboutData(aboutData);
 
     QCommandLineParser *cmdArgs = app.cmdArgs();
@@ -50,7 +38,7 @@ int main(int argc, char **argv)
         exit(0);
     }
 
-    auto *jots = new KJotsMain;
+    auto jots = new KJotsMain;
     if (app.isSessionRestored()) {
         if (KJotsMain::canBeRestored(1)) {
             jots->restore(1);
