@@ -1,23 +1,10 @@
 /*
     This file is part of KJots.
 
-    Copyright (c) 2009 - 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Tobias Koenig <tokoe@kde.org>
                   2020 Igor Poboiko <igor.poboiko@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "standardnoteactionmanager.h"
@@ -26,13 +13,14 @@
 #include <QColorDialog>
 #include <QItemSelectionModel>
 
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiCore/CollectionModifyJob>
-#include <AkonadiCore/ItemModifyJob>
-#include <Akonadi/Notes/NoteUtils>
+#include <akonadi_version.h>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/CollectionModifyJob>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/NoteUtils>
 
-#include <KXmlGui/KActionCollection>
+#include <KActionCollection>
 #include <KLocalizedString>
 
 #include "notecreatorandselector.h"
@@ -485,12 +473,12 @@ public:
             collection = collections.first();
         } else {
             const Item::List items = mParent->selectedItems();
-            if (items.count() == 0) {
+            if (items.isEmpty()) {
                 return;
             }
             collection = items.first().parentCollection();
         }
-        auto *creatorAndSelector = new NoteShared::NoteCreatorAndSelector(mCollectionSelectionModel, mItemSelectionModel, mParent);
+        auto creatorAndSelector = new NoteShared::NoteCreatorAndSelector(mCollectionSelectionModel, mItemSelectionModel, mParent);
         creatorAndSelector->createNote(collection);
     }
 
@@ -607,7 +595,7 @@ QAction *StandardNoteActionManager::createAction(Type type)
         action->setWhatsThis(i18n("Add a new note to a selected note book"));
         d->mActions.insert(CreateNote, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_note_create"), action);
-        d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_N));
+        d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_N));
         connect(action, &QAction::triggered, this, [this](){
            d->slotCreateNote();
         });
